#ifndef ST_SAVE_H
#define ST_SAVE_H

#include "state.h"

int goto_save(struct state *, struct state *);

#endif
